# iLADDER

**In-silico LADDER: Lung Aerosol Dosimetry for Drug and Environmental Research**

The development of predictive aerosol dosimetry models has been a major focus of environmental toxicology and pharmaceutical health research for decades. Simplified compartmental and one-dimensional models have been successful in predicting overall deposition but fail to accurately predict local deposition. Computational fluid-particle dynamics (CFPD) has been extensively used to study flow patterns and aerosol transport in idealistic, physiologically realistic and more recently patient-specific models of lung airways. To date, the challenge of predicting the deposition of inhaled aerosols under disease conditions is largely unmet. While 3D CFPD models provide the capability of including subject-specific lung abnormalities resulting from respiratory diseases, they typically only include a sub-region of the lung because of the prohibitive computational costs compared to simplified models.

The in-silico LADDER project aims at developing aerosol dosimetry multiscale models through a step-wise, modular integration of 3D computational fluid dynamic airflow and aerosol tracking CT-based lung models that extend from the nose and mouth to several generations of the conducting airways with each most distal 3D pulmonary airway bi-directionally coupled with lower dimensional airflow, aerosol transport, and tissue mechanics models to describe aerosol transport and deposition over the full respiratory system. The expected deliverables will be a suite of modular, multiscale models and standardized approaches for new model development that can be used by researchers, risk assessors, or clinicians to predict aerosol deposition in the lungs under healthy and disease conditions in addition to the underlying algorithms and framework for effective linking of user-defined, personalized aerosol dosimetry models in the future. As modules are fully validated and published, they will be made available to the research community on this platform.

This project is funded by grant U01-ES028669 from the National Institutes of Health (NIH)

### Sample Information

Please see below for more information 

**Add DOI associated with the reference**;;   
**Add hyperlinks to stl**;;   
**make an excel sheet to finalize it**


| Species | Strain            | Sex    | Sample ID       | STL                                | Mesh* | Reference |
| ------- | ----------------- | ------ | ------------ | ---------------------------------- | ---- | --------- |
| Rat     | Sprague Dawley    | Male   | Rat 8        | rat8.stl – Ref 1; Rat8\_nocyl.stl - Ref 2                  | Yes  | 1,2       |
| Rat     | Sprague Dawley    | Male   | Rat 026      |                                    |      |           |
| Monkey  |                   | Male   | Monkey 357   | [monkey.stl](/2012monkey)                        |      | 1         |
| Rabbit  | New Zealand White | Male   | Rabbit 2     | rabbit\_full\_1\_noCyl.stl         | Yes  | 3         |
| Human   |                   | Female | CT6576       | human\_nasal.stl – Ref 1           | Yes  | 1,2       |
|         |                   |        |              | hlung\_cyl.stl- Ref 1              |      |           |
|         |                   |        |              | human\_nasal\_nocyl\_1.stl – ref 2 |      |           |
| Human   |                   | Male   | Twin 1-18425 | Twin1\_Oral.stl                    | Yes  | 2         |
| Human   |                   | Male   | PD01         |                                    | Yes  | 3,4       |

*Note that meshes may be of out date and as such of limited use

### References

Add doi links

1.	RA Corley, S Kabilan, AP Kuprat, JP Carson, KR Minard, RE Jacob, et al. Comparative computational modeling of airflows and vapor dosimetry in the respiratory tracts of rat, monkey, and human. Toxicological Sciences 128 (2): 500-516, 2012. (10.1093/toxsci/kfs168)

2.	RA Corley, S Kabilan, AP Kuprat, JP Carson, RE Jacob, KR Minard, et al. Comparative risks of aldehyde constituents in cigarette smoke using transient computational fluid dynamics/physiologically based pharmacokinetic models of the rat and human respiratory tracts. Toxicological Sciences 146 (1), 65-88, 2015.

3.	S Kabilan, SR Suffield, KP Recknagle, RE Jacob, DR Einstein, AP Kuprat, et al. Computational fluid dynamics modeling of Bacillus anthracis spore deposition in rabbit and human respiratory airways. Journal of aerosol science 99, 64-77, 2016

4.	RA Corley, AP Kuprat, SR Suffield, S Kabilan, PM Hinderliter, K Yugulis, et al. New Approach Methodology for Assessing Inhalation Risks of a Contact Respiratory Cytotoxicant: Computational Fluid Dynamics-Based Aerosol Dosimetry Modeling for Cross-Species and In-Vitro Comparisons. Toxicological Sciences, in press, 2021

### Additional Information
| Sample       | Additional Info                                                                                                                                                                                                                                              |
| ------------ | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------ |
| Rat 8        | 9-10 weeks of age, ~300 g BW. Upper airways from one animal (nose-larynx) with the lung cast from another similar rat. This lung cast was one of three casts with Raabe Tables provided to ARA for the MPPD model (high resolution CT of in situ rigid cast) |
| Rat 026      |                                                                                                                                                                                                                                                              |
| Monkey 357   | 6 month-old, 1.3 kg male Rhesus with CT imaging of upper airways (nose through larynx) and MR imaging of silicone cast of lung that was inflation fixed to preserve topology prior to casting.                                                               |
| Rabbit 2     | CT of URT from 3.7 kg BW rabbit, with CT imaging of in situ lung casts from a male rabbit between 3-3.3 kg BW                                                                                                                                                |
| CT6576       | 84 Yr-old. Lung geometry including nasal passages or mouth (both available)                                                                                                                                                                                  |
| Twin 1-18425 | 18 yr old male, 72 kg BW.                                                                                                                                                                                                                                    |
| PD01         | 35-year-old, 150 lb, 67 in. tall                                                                                                                                                                                                                             |



### Reference DOI
| **Species  /  Strain**           | **Sex  /  Age  or  Weight**         | **Reference**                                                                                                                                                                      |
| -------------------------------- | ----------------------------------- | ---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| **Human**                        | Male  /  35  years  old,  68  kg   | [https://doi.org/10.1093/toxsci/kfab062](https://doi.org/10.1093/toxsci/kfab062)  [https://doi.org/10.1016/j.jaerosci.2016.01.011](https://doi.org/10.1016/j.jaerosci.2016.01.011) |
| **Human**                        | Male  / 18 years  old, 72 kg        | [https://doi.org/10.1093/toxsci/kfv071](https://doi.org/10.1093/toxsci/kfv071)                                                                                                     |
| **Human**                        | Female  80  years  old              | [https://doi.org/10.1093/toxsci/kfs168](https://doi.org/10.1093/toxsci/kfs168)  [https://doi.org/10.1093/toxsci/kfv071](https://doi.org/10.1093/toxsci/kfv071)                     |
| **Monkey /  Rhesus**             | Male  6 months                      | [https://doi.org/10.1093/toxsci/kfs168](https://doi.org/10.1093/toxsci/kfs168)                                                                                                     |
| **Rat / Sprague  Dawley**        | Male  /  9-10 weeks,  300  g        | [https://doi.org/10.1093/toxsci/kfs168](https://doi.org/10.1093/toxsci/kfs168)  [https://doi.org/10.1093/toxsci/kfv071](https://doi.org/10.1093/toxsci/kfv071)                     |
| **Rat / Sprague  Dawley**        | Male  /  9-10 weeks,  300  g        | [https://doi.org/10.1093/toxsci/kfs168](https://doi.org/10.1093/toxsci/kfs168)  [https://doi.org/10.1093/toxsci/kfv071](https://doi.org/10.1093/toxsci/kfv071)                     |
| **Rabbit / New  Zealand  white** | Male  / 3  – 3.7 kg                 | [https://doi.org/10.1016/j.jaerosci.2016.01.011](https://doi.org/10.1016/j.jaerosci.2016.01.011)                                                                                   |
| **Rabbit / New  Zealand  white** | Female  /  5–  6  months / 4-5  kg | [https://doi.org/10.1080/08958370802598005](https://doi.org/10.1080/08958370802598005)                                                                                |



